mlokNumericize: mlokNumericize

Description Usage Arguments Value Examples

View source: R/exploratory_analysis.R

Description

Accelerating the Data Cleansing Process

removes special characters from a string or a vector of strings and converts string into a numeric data type.

Usage

1

Arguments

x

the string or list of strings that needs to be converted into numeric data type

Value

x will be returned in numeric data type, removing special characters.

Examples

1
2
3
4
5
6
7
 # String:
 string <- " `~1#$%^&4*()_+"
 mlokNormalize(string)
 
 # Vector:
 vector <- c('$14.00', '5,000,000', '25%', '>$10,000')
 mlokNormalize(vector)

michael-lok/mlokFunctions documentation built on April 8, 2020, 9:34 p.m.