Description Usage Arguments Value Examples
View source: R/exploratory_analysis.R
Create correlation matrix with use of ggplot and reshape2 packages.
This is a funciton that helps to easily generate correlation matrices that can be used in reports. The input data must have at least two numeric variables, and will automatically exclude any fields that cannot be conformed into numeric data type.
1 | mlokCorMat(x)
|
x |
dataframe with at least two numeric fields. |
The red cells indicate negative correlation between variables; green indicates positive correlation.
1 2 3 4 5 6 | Name <- c('Otis', 'Michael', 'Sharon', 'Robin' )
Height <- c(207, 178, 164, 180)
Weight <- c(250, 156, 132, 149)
Profile <- data.frame(Name, Height, Weight)
mlokCorMat(Profile)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.